@@ -1,9 +1,9 @@
 import requests
-from .defaults import Defaults
+from .common_db import Common
 from typing import *
 
 
-class Base(Defaults):
+class Base(Common):  # Defaults -> Common -> Base -> Extras -> SmallWorld
 
     def __init__(self):
         """
@@ -12,6 +12,7 @@ class Base(Defaults):
         self.last_reply: requests.Response()  # debugging
         self.hit_list_id = -1
         self.session = requests.Session()
+        self.query_summary: Dict[str, Any] = {}
 
     def _retrieve(self, url: str, params: Dict[str, Any]) -> requests.Response:
         """
